==> haskell-vector-space-0.16-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-IHgwTSKP89V5R16HO0YgL3
key:                  vector-space-0.16-IHgwTSKP89V5R16HO0YgL3
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  980f17d37f273eb8ac2c26cd6a77f842
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-IHgwTSKP89V5R16HO0YgL3
depends:
    Boolean-0.2.4-2CMdlDEnACACCcpvBHLEzn
    MemoTrie-0.6.11-cL6zB9ts2k52DQWSjqQS7
    NumInstances-1.4-KqRAOAeLv9H1q3OPA3mDpV base-4.16.4.0

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-space-0.16-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-7NYimeUF6ZtLT2R9GJskwr
key:                  vector-space-0.16-7NYimeUF6ZtLT2R9GJskwr
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  77b5a5f59f36e637a8e9842081cd4eee
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-7NYimeUF6ZtLT2R9GJskwr
depends:
    Boolean-0.2.4-2CMdlDEnACACCcpvBHLEzn
    MemoTrie-0.6.11-HcqF5jE52LC1pgxWHdKckN
    NumInstances-1.4-KqRAOAeLv9H1q3OPA3mDpV base-4.16.4.0

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
